@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "perspective" "2.21"
+(define-package "perspective" "20251104.1408"
   "Switch between named \"perspectives\" of the editor."
   '((emacs  "24.4")
     (cl-lib "0.5"))
   :url "http://github.com/nex3/perspective-el"
-  :commit "64ef5eaaab9e7564e8b9788ce6d0e2359daf5dca"
-  :revdesc "2.21-0-g64ef5eaaab9e"
+  :commit "7f47c9a7be7b7d03f6d8430c84eec80ae5896699"
+  :revdesc "7f47c9a7be7b"
   :keywords '("workspace" "convenience" "frames")
   :authors '(("Natalie Weizenbaum" . "nex342@gmail.com"))
   :maintainers '(("Natalie Weizenbaum" . "nex342@gmail.com")))
